Changelog
=========

All notable changes to this project will be documented in this file.

0.1.2
-----

- Update ``ProfileGenerator`` constructor and ``ProfileGenerator.render`` arguments.

0.1.1
-----

- Add ``MANIFEST.in``.

0.1.0
-----

- Initial release.
